@@ -52,7 +52,7 @@ int
 main (int argc, char *argv[])
 {
 	GtkWidget *window;
-	GtkWidget *menu_about, *menu_copy, *menu_clear_history;
+	GtkWidget *menu_quit, *menu_about, *menu_copy, *menu_clear_history;
 	GladeXML *xml;
 	GtkWidget *notebook;
 	const gchar *dialog = DATADIR "gnome-nettool.glade";
@@ -74,6 +74,8 @@ main (int argc, char *argv[])
 	static gchar *lookup_input = NULL;
 	static gchar *finger_input = NULL;
 	static gchar *whois_input = NULL;
+	GError *error = NULL;
+
 	GOptionEntry options[] = {
 		{ "info", 'i', 0, G_OPTION_ARG_STRING, &info_input,
  		  N_("Load information for a network device"),
@@ -116,7 +118,10 @@ main (int argc, char *argv[])
 	textdomain (GETTEXT_PACKAGE);
 #endif
 
-	gtk_init_with_args (&argc, &argv,NULL,options,NULL,NULL);
+	if (!gtk_init_with_args (&argc, &argv, NULL, options, NULL, &error)) {
+		g_print ("%s\n\n", error->message);
+		return -1;
+	}
 
 	if (!g_file_test (dialog, G_FILE_TEST_EXISTS)) {
 		g_critical (_("The file %s doesn't exist, "
@@ -210,6 +215,11 @@ main (int argc, char *argv[])
 	g_object_set_data (G_OBJECT (notebook), "finger", finger);
 	g_object_set_data (G_OBJECT (notebook), "whois", whois);
 	
+	menu_quit = glade_xml_get_widget (xml, "m_quit");
+	
+	g_signal_connect (G_OBJECT (menu_quit), "activate",
+			  G_CALLBACK (gn_quit_app),
+			  NULL);
 	
 	menu_about = glade_xml_get_widget (xml, "m_about");
 
